Treeize

Struct Treeize 

pub struct Treeize<T> { /* private fields */ }
Treeize is generic node-graph container.

It holds graph state - positioned nodes and wires between their pins. It can be rendered using Treeize::show.

Implementations

Source

impl<T> Treeize<T>

pub fn show<V>( &mut self, viewer: &mut V, style: &TreeizeStyle, id_salt: impl Hash, ui: &mut Ui, )
where V: TreeizeViewer<T>,

Render Treeize using given viewer and style into the Ui.

Source

impl<T> Treeize<T>

pub fn new() -> Self

Create a new empty Treeize.

Examples
let treeize = Treeize::<()>::new();
pub fn insert_node(&mut self, pos: Pos2, node: T) -> NodeId

Adds a node to the Treeize. Returns the index of the node.

Examples
let mut treeize = Treeize::<()>::new();
treeize.insert_node(egui::pos2(0.0, 0.0), ());
pub fn insert_node_collapsed(&mut self, pos: Pos2, node: T) -> NodeId

Adds a node to the Treeize in collapsed state. Returns the index of the node.

Examples
let mut treeize = Treeize::<()>::new();
treeize.insert_node_collapsed(egui::pos2(0.0, 0.0), ());
pub fn open_node(&mut self, node: NodeId, open: bool)

Opens or collapses a node.

Panics

Panics if the node does not exist.

pub fn remove_node(&mut self, idx: NodeId) -> T

Removes a node from the Treeize. Returns the node if it was removed.

Panics

Panics if the node does not exist.

Examples
let mut treeize = Treeize::<()>::new();
let node = treeize.insert_node(egui::pos2(0.0, 0.0), ());
treeize.remove_node(node);
pub fn clear(&mut self) -> usize

Removes all nodes from the Treeize. Returns number of removed nodes.

Examples
let mut treeize = Treeize::<()>::new();
treeize.clear();
pub fn connect(&mut self, from: OutPinId, to: InPinId) -> bool

Connects two nodes. Returns true if the connection was successful. Returns false if the connection already exists.

Panics

Panics if either node does not exist.

pub fn disconnect(&mut self, from: OutPinId, to: InPinId) -> bool

Disconnects two nodes. Returns true if the connection was removed.

Panics

Panics if either node does not exist.

pub fn drop_inputs(&mut self, pin: InPinId) -> usize

Removes all connections to the node’s pin.

Returns number of removed connections.

Panics

Panics if the node does not exist.

pub fn drop_outputs(&mut self, pin: OutPinId) -> usize

Removes all connections from the node’s pin. Returns number of removed connections.

Panics

Panics if the node does not exist.

pub fn get_node(&self, idx: NodeId) -> Option<&T>

Returns reference to the node.

pub fn get_node_mut(&mut self, idx: NodeId) -> Option<&mut T>

Returns mutable reference to the node.

pub fn get_node_info(&self, idx: NodeId) -> Option<&Node<T>>

Returns reference to the node data.

pub fn get_node_info_mut(&mut self, idx: NodeId) -> Option<&mut Node<T>>

Returns mutable reference to the node data.

pub fn nodes(&self) -> NodesIter<'_, T>

Iterates over shared references to each node.

pub fn nodes_mut(&mut self) -> NodesIterMut<'_, T>

Iterates over mutable references to each node.

pub fn nodes_pos(&self) -> NodesPosIter<'_, T>

Iterates over shared references to each node and its position.

pub fn nodes_pos_mut(&mut self) -> NodesPosIterMut<'_, T>

Iterates over mutable references to each node and its position.

pub fn node_ids(&self) -> NodesIdsIter<'_, T>

Iterates over shared references to each node and its identifier.

pub fn nodes_ids_mut(&mut self) -> NodesIdsIterMut<'_, T>

Iterates over mutable references to each node and its identifier.

pub fn nodes_pos_ids(&self) -> NodesPosIdsIter<'_, T>

Iterates over shared references to each node, its position and its identifier.

pub fn nodes_pos_ids_mut(&mut self) -> NodesPosIdsIterMut<'_, T>

Iterates over mutable references to each node, its position and its identifier.

pub fn nodes_info(&self) -> NodeInfoIter<'_, T>

Iterates over shared references to each node data.

pub fn nodes_info_mut(&mut self) -> NodeInfoIterMut<'_, T>

Iterates over mutable references to each node data.

pub fn nodes_ids_data(&self) -> NodeIdsDataIter<'_, T>

Iterates over shared references to each node id and data.

pub fn nodes_ids_data_mut(&mut self) -> NodeIdsDataIterMut<'_, T>

Iterates over mutable references to each node id and data.

pub fn wires(&self) -> impl Iterator<Item = (OutPinId, InPinId)> + '_

Iterates over wires.

pub fn in_pin(&self, pin: InPinId) -> InPin

Returns input pin of the node.

pub fn out_pin(&self, pin: OutPinId) -> OutPin

Returns output pin of the node.