Module ui

Module ui 

This module provides functionality for showing Treeize graph in Ui.

Structs

Grid
Grid background pattern. Use TreeizeStyle::background_pattern_stroke for change stroke options
NodeLayout
Controls how node elements are laid out.
PinInfo
Information about a pin returned by TreeizeViewer::show_input and TreeizeViewer::show_output.
PinWireInfo
Contains information about a pin’s wire. Used to draw the wire. When two pins are connected, the wire is drawn between them, using merged PinWireInfo from both pins.
SelectionStyle
Controls style of node selection rect.
TreeizeLayoutSignal
Signal to layout the treeize.
TreeizeStyle
Style for rendering Treeize.
TreeizeWidget
Widget to display Treeize graph in Ui.

Enums

AnyPins
In the current context, these are the I/O pins of the ‘source’ node that the newly created node’s I/O pins will connect to.
BackgroundPattern
Background pattern show beneath nodes and wires.
NodeLayoutKind
Controls how header, pins, body are placed in the node.
PinPlacement
Controls how pins are placed in the node.
PinShape
Shape of a pin.
WireLayer
Layer where wires are rendered.
WireStyle
Controls style in which wire is rendered.

Traits

TreeizePin
Uses Painter to draw a pin.
TreeizeViewer
TreeizeViewer is a trait for viewing a Treeize.

Functions

get_selected_nodes
Returns nodes selected in the UI for the TreeizeWidget with same ID.