pub enum NodeLayoutKind {
Compact,
}Expand description
Controls how header, pins, body are placed in the node.
Variants
Compact
Input pins, body and output pins are placed horizontally.
+———In–––––+ | Header | +––+———–+––+ | | | Body | | | +––––Out–––––+