pub struct NodeLayout {
pub kind: NodeLayoutKind,
pub min_pin_row_height: f32,
pub equal_pin_row_heights: bool,
}Expand description
Controls how node elements are laid out.
Fields
kind: NodeLayoutKindControls method of laying out node elements.
min_pin_row_height: f32Controls minimal height of pin rows.
equal_pin_row_heights: boolControls how pin rows heights are set. If true, all pin rows will have the same height, matching the largest content. False by default.
Implementations
Sourceimpl NodeLayout
impl NodeLayout
Sourcepub const fn coil() -> Self
pub const fn coil() -> Self
Creates new NodeLayout with Coil kind and flexible pin heights.
Sourcepub const fn sandwich() -> Self
pub const fn sandwich() -> Self
Creates new NodeLayout with Sandwich kind and flexible pin heights.
Sourcepub const fn flipped_sandwich() -> Self
pub const fn flipped_sandwich() -> Self
Creates new NodeLayout with FlippedSandwich kind and flexible pin heights.
Sourcepub const fn with_equal_pin_rows(self) -> Self
pub const fn with_equal_pin_rows(self) -> Self
Returns new NodeLayout with same kind and specified pin heights.
Sourcepub const fn with_min_pin_row_height(self, min_pin_row_height: f32) -> Self
pub const fn with_min_pin_row_height(self, min_pin_row_height: f32) -> Self
Returns new NodeLayout with same kind and specified minimum pin row height.