TreeizeStyle

Struct TreeizeStyle 

pub struct TreeizeStyle {
Show 27 fields pub node_layout: Option<NodeLayout>, pub node_frame: Option<Frame>, pub header_frame: Option<Frame>, pub header_drag_space: Option<Vec2>, pub collapsible: Option<bool>, pub pin_size: Option<f32>, pub pin_fill: Option<Color32>, pub pin_stroke: Option<Stroke>, pub pin_shape: Option<PinShape>, pub pin_placement: Option<PinPlacement>, pub wire_width: Option<f32>, pub wire_frame_size: Option<f32>, pub downscale_wire_frame: Option<bool>, pub upscale_wire_frame: Option<bool>, pub wire_style: Option<WireStyle>, pub wire_layer: Option<WireLayer>, pub bg_frame: Option<Frame>, pub bg_pattern: Option<BackgroundPattern>, pub bg_pattern_stroke: Option<Stroke>, pub min_scale: Option<f32>, pub max_scale: Option<f32>, pub select_stoke: Option<Stroke>, pub select_fill: Option<Color32>, pub select_rect_contained: Option<bool>, pub select_style: Option<SelectionStyle>, pub crisp_magnified_text: Option<bool>, pub wire_smoothness: Option<f32>, /* private fields */
}
Style for rendering Treeize.

Fields

node_layout: Option<NodeLayout>

Controls how nodes are laid out. Defaults to [NodeLayoutKind::Coil].

node_frame: Option<Frame>

Frame used to draw nodes. Defaults to Frame::window constructed from current ui’s style.

header_frame: Option<Frame>

Frame used to draw node headers. Defaults to [node_frame] without shadow and transparent fill.

If set, it should not have shadow and fill should be either opaque of fully transparent unless layering of header fill color with node fill color is desired.

header_drag_space: Option<Vec2>

Blank space for dragging node by its header. Elements in the header are placed after this space.

collapsible: Option<bool>

Whether nodes can be collapsed. If true, headers will have collapsing button. When collapsed, node will not show its pins and body.

pin_size: Option<f32>

Size of pins.

pin_fill: Option<Color32>

Default fill color for pins.

pin_stroke: Option<Stroke>

Default stroke for pins.

pin_shape: Option<PinShape>

Shape of pins.

pin_placement: Option<PinPlacement>

Placement of pins.

wire_width: Option<f32>

Width of wires.

wire_frame_size: Option<f32>

Size of wire frame which controls curvature of wires.

downscale_wire_frame: Option<bool>

Whether to downscale wire frame when nodes are close.

upscale_wire_frame: Option<bool>

Weather to upscale wire frame when nodes are far.

wire_style: Option<WireStyle>

Controls default style of wires.

wire_layer: Option<WireLayer>

Layer where wires are rendered.

bg_frame: Option<Frame>

Frame used to draw background

bg_pattern: Option<BackgroundPattern>

Background pattern. Defaults to BackgroundPattern::Grid.

bg_pattern_stroke: Option<Stroke>

Stroke for background pattern. Defaults to ui.visuals().widgets.noninteractive.bg_stroke.

min_scale: Option<f32>

Minimum viewport scale that can be set.

max_scale: Option<f32>

Maximum viewport scale that can be set.

select_stoke: Option<Stroke>

Stroke for selection.

select_fill: Option<Color32>

Fill for selection.

select_rect_contained: Option<bool>

Flag to control how rect selection works. If set to true, only nodes fully contained in selection rect will be selected. If set to false, nodes intersecting with selection rect will be selected.

select_style: Option<SelectionStyle>

Style for node selection.

crisp_magnified_text: Option<bool>

Controls whether to show magnified text in crisp mode. This zooms UI style to max scale and scales down the scene.

wire_smoothness: Option<f32>

Controls smoothness of wire curves.

Implementations

Source

impl TreeizeStyle

pub const fn new() -> Self

Creates new TreeizeStyle filled with default values.