Structs
- Grid
- Grid background pattern.
Use
TreeizeStyle::background_pattern_strokefor change stroke options - Node
Layout - Controls how node elements are laid out.
- PinInfo
- Information about a pin returned by
TreeizeViewer::show_inputandTreeizeViewer::show_output. - PinWire
Info - Contains information about a pin’s wire.
Used to draw the wire.
When two pins are connected, the wire is drawn between them,
using merged
PinWireInfofrom both pins. - Selection
Style - Controls style of node selection rect.
- Treeize
Layout Signal - Signal to layout the treeize.
- Treeize
Style - Style for rendering Treeize.
- Treeize
Widget - Widget to display
Treeizegraph inUi.
Enums
- AnyPins
- In the current context, these are the I/O pins of the ‘source’ node that the newly created node’s I/O pins will connect to.
- Background
Pattern - Background pattern show beneath nodes and wires.
- Node
Layout Kind - Controls how header, pins, body are placed in the node.
- PinPlacement
- Controls how pins are placed in the node.
- PinShape
- Shape of a pin.
- Wire
Layer - Layer where wires are rendered.
- Wire
Style - Controls style in which wire is rendered.
Traits
- Treeize
Pin - Uses
Painterto draw a pin. - Treeize
Viewer TreeizeVieweris a trait for viewing a Treeize.
Functions
- get_
selected_ nodes - Returns nodes selected in the UI for the
TreeizeWidgetwith same ID.