pub enum NodeLayoutKind {
Coil,
Sandwich,
FlippedSandwich,
}Expand description
Controls how header, pins, body and footer are placed in the node.
Variants
Coil
Input pins, body and output pins are placed horizontally. With header on top and footer on bottom.
+———————+ | Header | +––+———–+––+ | In | | Out| | In | Body | Out| | In | | Out| | In | | | +––+———–+––+ | Footer | +———————+
Sandwich
All elements are placed in vertical stack. Header is on top, then input pins, body, output pins and footer.
+———————+ | Header | +———————+ | In | | In | | In | | In | +———————+ | Body | +———————+ | Out | | Out | | Out | +———————+ | Footer | +———————+
FlippedSandwich
All elements are placed in vertical stack. Header is on top, then output pins, body, input pins and footer.
+———————+ | Header | +———————+ | Out | | Out | | Out | +———————+ | Body | +———————+ | In | | In | | In | | In | +———————+ | Footer | +———————+