TreeizeWidget

Struct TreeizeWidget 

pub struct TreeizeWidget { /* private fields */ }
Widget to display Treeize graph in Ui.

Implementations

Source

impl TreeizeWidget

pub fn get_selected_nodes(self, ui: &Ui) -> Vec<NodeId>

Returns list of nodes selected in the UI for the TreeizeWidget with same id.

Use same Ui instance that was used in TreeizeWidget::show.

pub fn get_selected_nodes_at(self, ui_id: Id, ctx: &Context) -> Vec<NodeId>

Returns list of nodes selected in the UI for the TreeizeWidget with same id.

ui_id must be the Id of the Ui instance that was used in TreeizeWidget::show.

Source

impl TreeizeWidget

pub fn new() -> Self

Returns new TreeizeWidget with default parameters.

pub const fn id(self, id: Id) -> Self

Assign an explicit and globally unique Id.

Use this if you want to persist the state of the widget when it changes position in the widget hierarchy.

Prefer using TreeizeWidget::id_salt otherwise.

pub fn id_salt(self, id_salt: impl Hash) -> Self

Assign a source for the unique Id

It must be locally unique for the current Ui hierarchy position.

Ignored if TreeizeWidget::id was set.

pub const fn style(self, style: TreeizeStyle) -> Self

Set style parameters for the Treeize widget.

pub const fn min_size(self, min_size: Vec2) -> Self

Set minimum size of the Treeize widget.

pub const fn max_size(self, max_size: Vec2) -> Self

Set maximum size of the Treeize widget.

pub fn show<T, V>( &self, treeize: &mut Treeize<T>, viewer: &mut V, ui: &mut Ui, center_signal: Option<bool>, layout_signal: Option<&TreeizeLayoutSignal>, ) -> Response
where V: TreeizeViewer<T>,

Render Treeize using given viewer and style into the Ui.